<?php

namespace Drupal\dyna_tree\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class DynaTreeSettingsForm extends ConfigFormBase {
    
    /**
     * Config settings.
     *
     * @var string
     */
    const SETTINGS = 'dynatree.settings';
    
    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'dynatree_admin_settings';
    }
    
    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames() {
        return [
            static::SETTINGS,
        ];
    }
    
    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        $config = $this->config(static::SETTINGS);
        
        if( empty( $config->get('dynatree_button') ) ) {
            $config->set('dynatree_button', 'Search');
        }
        
        $form['dynatree_button'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Dynatree Search Button Name'),
            '#default_value' => $config->get('dynatree_button'),
        ];
        
        return parent::buildForm($form, $form_state);
    }
    
    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        // Retrieve the configuration.
        $this->configFactory->getEditable(static::SETTINGS)
        // Set the submitted configuration setting.
        ->set('dynatree_button', $form_state->getValue('dynatree_button'))
        ->save();
        
        parent::submitForm($form, $form_state);
    }
    
}